@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
 our $DATE = '2015-11-13'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -109,8 +109,15 @@ our $scenario = {
         {
             name => 'num10',
             args => {
-                set1 => [qw/1 2 3 4 5 6 7 8 9 10/],
-                set2 => [qw/2 3 4 5 6 7 8 9 10 11/],
+                set1 => [1..10],
+                set2 => [2..11],
+            },
+        },
+        {
+            name => 'num100',
+            args => {
+                set1 => [1..100],
+                set2 => [2..101],
             },
         },
     ],
@@ -131,7 +138,7 @@ Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, in
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-13.
+This document describes version 0.03 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2015-11-13.
 
 =head1 SYNOPSIS
 
